@@ -195,6 +195,7 @@ class LatexProject:
                             twitter=user.twitter,
                             affiliation=user.affiliation,
                             orcid=user.orcid,
+                            curvenote=f"https://curvenote.com/@{user.username}"
                         )
                     )
             elif author.plain:
@@ -202,17 +203,25 @@ class LatexProject:
             else:
                 logging.info("found empty author, skipping...")
 
+        SHORT_TITLE_SIZE = 30
+        short_title = (
+            first.article.title
+            if len(first.article.title) < SHORT_TITLE_SIZE
+            else f"{first.article.title[:(SHORT_TITLE_SIZE-3)]}..."
+        )
+
         data = DocModel(
             dict(
                 doc=dict(
                     oxalink=first.article.oxalink(self._session.site_url),
                     title=escape_latex(first.article.title),
+                    short_title=escape_latex(short_title),
+                    description=escape_latex(first.article.description if first.article.description else ""),
                     authors=authors,
                     date=first.article.date,
                     tags=[escape_latex(tag) for tag in first.article.tags],
                 ),
                 tagged=tagged_content,
-                curvenote=dict(defs=r"\input{curvenote.def}"),
                 options=dict(docclass=""),
             )
         )
