@@ -26,7 +26,7 @@ class TemplateRenderer:
         Define our own custom jinja environment that plays nicely with LaTeX
 
         [# #] - blocks
-        [[ ]] - variables
+        [- -] - variables
         ## ## - comments
 
         disabled line statements
@@ -35,8 +35,8 @@ class TemplateRenderer:
         self.jinja = Environment(
             block_start_string=r"[#",
             block_end_string="#]",
-            variable_start_string=r"[[",
-            variable_end_string="]]",
+            variable_start_string=r"[-",
+            variable_end_string="-]",
             comment_start_string=r"%#",
             comment_end_string="#%",
             trim_blocks=True,
