@@ -8,4 +8,6 @@ from .CodeSchemaOption import CodeSchemaOption
 from .HideLinksSchemaOption import HideLinksSchemaOption
 from .RaggedBottomOption import RaggedBottomSchemaOption
 from .SloppySchemaOption import SloppySchemaOption
-from .CitepSchemaOption import CitepSchemaOption
+from .NatbibSchemaOption import NatbibSchemaOption
+from .BibstyleSchemaOption import BibstyleSchemaOption
+from .CitestyleSchemaOption import CitestyleSchemaOption
