@@ -24,11 +24,17 @@ from .run_regex_matchers import run_regex_matchers
 
 def split_remote_paths(remote_path: str) -> List[str]:
     """Splits a remote path into a list of block_paths or oxa_paths"""
-    matches = run_regex_matchers([
-            OXA_REGEX, UNPINNED_OXA_REGEX_ENDLINE,
-            UNPINNED_OXA_REGEX_INLINE, BLOCK_REGEX,
-            UNPINNED_BLOCK_REGEX_ENDLINE, UNPINNED_BLOCK_REGEX_INLINE
-            ], remote_path)
+    matches = run_regex_matchers(
+        [
+            OXA_REGEX,
+            UNPINNED_OXA_REGEX_ENDLINE,
+            UNPINNED_OXA_REGEX_INLINE,
+            BLOCK_REGEX,
+            UNPINNED_BLOCK_REGEX_ENDLINE,
+            UNPINNED_BLOCK_REGEX_INLINE,
+        ],
+        remote_path,
+    )
 
     if len(matches) == 0:
         return [remote_path]
@@ -90,7 +96,9 @@ def localize_references_from_content_block(
             bibtex_content: str = version.content
             _, plain_tag = parse_cite_tag_from_bibtex(bibtex_content)
 
-            reference_item = LocalMarker(plain_tag, remote_path, plain_tag, bibtex_content)
+            reference_item = LocalMarker(
+                plain_tag, remote_path, plain_tag, bibtex_content
+            )
             reference_list.append(reference_item)
             existing_reference = reference_item
             logging.info("using new reference %s", existing_reference.marker)
