@@ -4,7 +4,10 @@ from typing import List
 from .localize_images import ImageSummary
 from .run_regex_matchers import run_regex_matchers
 
-def patch_local_images_from_tex_block(regex_matchers: List[str], content: str) -> ImageSummary:
+
+def patch_local_images_from_tex_block(
+    regex_matchers: List[str], content: str
+) -> ImageSummary:
     """
     Take a piece of tex content that we expect to contain only one includegraphics directive
     get the remote path, assign a new local path and retrun a structure that can be parsed
@@ -18,13 +21,11 @@ def patch_local_images_from_tex_block(regex_matchers: List[str], content: str) -
         remote_path = match[1]
         hash_segment = remote_path[6:]
         local_segment = hash_segment.replace("/", "_")
-        local_path = remote_path.replace(
-                "block:", "images/"
-            ).replace(
-                "oxa:", "images/"
-            ).replace(
-                hash_segment, local_segment
-            )
+        local_path = (
+            remote_path.replace("block:", "images/")
+            .replace("oxa:", "images/")
+            .replace(hash_segment, local_segment)
+        )
         updated_content = updated_content.replace(remote_path, local_path)
         remote_paths.append(remote_path)
         local_paths.append(local_path)
